@@ -641,6 +641,7 @@ public:
 		Handler handler, logstate;
 		const char *name;
 		timeout_t timeout;
+		bool peering;
 		Name *menu;
 		unsigned stack;
 		Line *lib;
@@ -2167,6 +2168,12 @@ protected:
 public:
 	Traffic call_attempts, call_complete;
 
+	inline bool isDTMF(void)
+		{return dtmf;};
+
+	inline bool isPeering(void)
+		{return state.peering;};
+
 	/**
 	 * Process interpreter session symbols.
 	 *
@@ -2533,6 +2540,11 @@ public:
 	 */
 	bool isJoined(void);
 
+	/**
+	 * Return state disconnecting or idle...
+	 */
+	bool isDisconnecting(void);
+
 	/**
 	 * Return parent answer timer, if joining.
 	 *
