@@ -262,6 +262,15 @@ bool BayonneSession::isJoined(void)
 	return false;
 }
 
+bool BayonneSession::isDisconnecting(void)
+{
+	if(state.handler == &BayonneSession::stateIdle)
+		return true;
+	if(state.handler == &BayonneSession::stateHangup)
+		return true;
+	return false;
+}
+
 timeout_t BayonneSession::getJoinTimer(void)
 {
 	if(state.handler == &BayonneSession::stateStart)
