@@ -903,7 +903,7 @@ bool BayonneSession::stateConnect(Event *event)
 {
 	Event cancel;
 	BayonneSession *s;
-	bool dtmf, rtn;
+	bool dtmf, rtn, hangup;
 
         if(enterTone(event))
                 return true;
@@ -974,8 +974,10 @@ failed:
         case PEER_WAITING:
 		s = getSid(state.tone.sessionid);
 		dtmf = state.tone.dtmf;
+		hangup = state.tone.hangup;
 		state.timeout = state.tone.duration;
 		state.join.dtmf = dtmf;
+		state.join.hangup = hangup;
 		state.join.dial = NULL;
 		state.join.exit = NULL;
 		state.join.peer = s;
@@ -1303,12 +1305,20 @@ bool BayonneSession::stateJoin(Event *event)
 	return rtn;
 
 part:
-	if(!scriptEvent(msg))
-		if(!signalScript(SIGNAL_PART))
-			error(err);
-	setRunning();
+	if(scriptEvent(msg))
+		state.join.hangup = false;
+	else if(signalScript(SIGNAL_PART))
+		state.join.hangup = false;
+	else if(!state.join.hangup)
+		error(err);
+
+	if(!state.join.hangup)
+		setRunning();
+
 	event->id = EXIT_PARTING;
 	enterJoin(event);
+	if(state.join.hangup)
+		setState(STATE_HANGUP);
 	return true;
 }
 		
@@ -1866,6 +1876,7 @@ bool BayonneSession::stateSeize(Event *event)
 			setRunning();
 			return true;
 		}
+		setSymbol("script.error", "session-invalid");
 		setState(STATE_HANGUP);
 		return true;
 	case DIAL_DND:
@@ -1875,6 +1886,7 @@ bool BayonneSession::stateSeize(Event *event)
                         setRunning();
                         return true;
                 }
+		setSymbol("script.error", "session-dnd");
                 setState(STATE_HANGUP);
                 return true;		
 	case DIAL_BUSY:
@@ -1884,6 +1896,7 @@ bool BayonneSession::stateSeize(Event *event)
 			setRunning();
 			return true;
 		}
+		setSymbol("script.error", "session-busy");
 		setState(STATE_HANGUP);
 		return true;
 	case DIAL_CONNECT:
@@ -1897,6 +1910,7 @@ bool BayonneSession::stateSeize(Event *event)
 			setRunning();
 			return true;
 		}
+		setSymbol("script.error", "session-away");
 		setState(STATE_HANGUP);
 		return true;
 	case DIAL_TIMEOUT:
@@ -1907,6 +1921,7 @@ noanswer:
 			setRunning();
 			return true;
 		}
+		setSymbol("script.error", "session-noanswer");
 		setState(STATE_HANGUP);
 		return true;
 	case TIMER_EXPIRED:
@@ -1929,7 +1944,8 @@ failure:
 			setRunning();
 			return true;
 		}
-		slog.debug("%s: no dialtone; exiting", logname); 
+		slog.debug("%s: no dialtone; exiting", logname);
+		setSymbol("script.error", "session-failed");
 		setState(STATE_HANGUP);
 		return true;
 	case LINE_DISCONNECT:
@@ -1971,6 +1987,7 @@ bool BayonneSession::stateRunning(Event *event)
 			default:
 				incIncomingComplete();
 			}			
+			BayonneService::active(this);
 		}
 		if(state.pid)
 			newTid();
@@ -2023,7 +2040,10 @@ bool BayonneSession::stateHangup(Event *event)
 	BayonneSession *parent = NULL;
 
 	if(event->id == ENTER_STATE)
+	{
 		decActiveCalls();
+		BayonneService::detach(this);
+	}
 
         if(enterHangup(event))
                 return true; 
