@@ -1253,12 +1253,12 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(ext)
 	{
 		if(!ScriptChecks::useKeywords(line, 
-			"=secret=encoding=framing=dtmf=user=count=device=info"))
+			"=peering=secret=encoding=framing=dtmf=user=count=device=info"))
 				return "invalid keywords used for sip external";
 	}
 	else if(!ScriptChecks::useKeywords(line, 
 		"=uri=timeout=server=proxy=userid=secret=type=realm=dtmf"
-		"=limit=public=encoding=framing=local=caller=service"))
+		"=limit=public=encoding=framing=local=caller=service=peering"))
 			return "invalid keywords for sip registry";
 
 
@@ -1273,9 +1273,13 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	reg->realm = ScriptChecks::findKeyword(line, "realm");
 	reg->type = ScriptChecks::findKeyword(line, "type");
 	reg->dtmf = ScriptChecks::findKeyword(line, "dtmf");
+	reg->peering = ScriptChecks::findKeyword(line, "peering");
 	reg->encoding = ScriptChecks::findKeyword(line, "encoding");
 	reg->caller = ScriptChecks::findKeyword(line, "caller");
 
+	if(reg->peering)
+		reg->encoding = reg->peering;
+
 	if(ext)
 		reg->localid = ScriptChecks::findKeyword(line, "user");
 	else
@@ -1354,6 +1358,9 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 			if(cp)
 				reg->framing = atol(cp);
 		}
+		cp = cfg->getLast("peering");
+		if(cp)
+			reg->encoding = reg->peering = ip->dupString(cp);
 		delete cfg;
 	}
 #endif
@@ -1932,7 +1939,7 @@ exitcall:
 				remote_sdp = eXosip_get_sdp_info(sevent->response);
 			}
 			eXosip_unlock();
-			data_rtpmap = session->getSymbol("session.rtpmap");
+			data_rtpmap = session->getSymbol("session.sdp_encoding");
                         cp = session->getSymbol("session.ip_public");
 			if(local_sdp && remote_sdp && session->dtmf_payload)
                         	snprintf(buf, sizeof(buf),
@@ -2849,8 +2856,11 @@ sip415:
 
 			snprintf(cbuf, sizeof(cbuf), "a=rtpmap:%d %s",
 				session->data_payload, data_rtpmap);
-			session->setConst("session.rtpmap", cbuf);
-			data_rtpmap = session->getSymbol("session.rtpmap");
+			session->setConst("session.sdp_encoding", cbuf);
+			data_rtpmap = session->getSymbol("session.sdp_encoding");
+
+			if(reg && reg->peering)
+				session->setConst("session.sdp_peering", data_rtpmap);
 
 			if(session->dtmf_payload)
 				snprintf(cbuf, sizeof(cbuf),
@@ -2879,6 +2889,10 @@ sip415:
 
 			if(session->dtmf_payload)
 			{
+				snprintf(cbuf, sizeof(cbuf),
+					"a=rtpmap:%d telephone-events/8000",
+					session->dtmf_payload);
+				session->setConst("session.sdp_events", cbuf);
 				snprintf(cbuf, sizeof(cbuf),
 					"a=rtpmap:%d telephone-events/8000\r\n",
 					session->dtmf_payload);
