@@ -126,6 +126,7 @@ public:
 	const char *realm;
 	const char *dtmf;
 	const char *encoding;
+	const char *peering;
 	const char *caller;
 	timeout_t framing;
 	int regid;
@@ -299,6 +300,7 @@ protected:
 	AudioCodec *peer_codec;
 	uint8 dtmf_payload, data_payload;
 	bool dtmf_sipinfo;
+	bool reinvite;
 	volatile bool dtmf_inband;
 	volatile time_t session_timer;
 
@@ -310,6 +312,9 @@ protected:
 
 	void setDTMFMode(const char *mode);
 
+	void redirect(const char *target, const char *encoding, unsigned char data, unsigned char dtmf);
+	void reconnect(void);
+
 public:
 	Session(timeslot_t ts);
 	~Session();
@@ -369,6 +374,8 @@ public:
 
 	void setEncoding(const char *encoding, timeout_t framing);
 
+	unsigned char peerEncoding(BayonneSession *s);
+	unsigned char peerEvents(BayonneSession *s);
 };
 
 }
