@@ -358,10 +358,7 @@ void RTPStream::run(void)
 	for(;;)
 	{
 		if(session->rtp_flag)
-		{
-			slog.debug("%s: going active", session->getLogname());
 			runActive();
-		}
 		else
 			Thread::sleep(50);
 	}
@@ -386,8 +383,25 @@ void RTPStream::runActive(void)
 	unsigned short pps = (unsigned short)(1000 / info.framing);
 	unsigned short dtmfoffset = (unsigned short)(info.rate / pps);
 	BayonneSession *joined;
+	Registry *reg = NULL;
+	unsigned long seq = 0;
 //	unsigned ecount = 0;
 	time_t now;
+	const char *cp;
+
+	cp = session->getSymbol("session.registry");
+	if(cp)
+		reg = (Registry *)((session->getImage())->getPointer(cp));
+
+	cp = session->getSymbol("session.sequence");
+	if(cp)
+		seq = atol(cp);
+
+	if(reg)
+		slog.debug("%s: going active; associated with %s",
+			session->getLogname(), reg->userid);
+	else
+		slog.debug("%s: going active", session->getLogname());
 
 	jitter = Driver::sip.jitter;
 	jsend = Driver::sip.jitter;
@@ -428,11 +442,27 @@ void RTPStream::runActive(void)
 		}
 
                 incTimer(info.framing);
+		if(reg)
+		{
+			if(!reg->isActive() || reg->traffic->sequence != seq)
+			{
+				slog.debug("%s: registration %s lost",
+					session->getLogname(), reg->userid);
+
+				memset(&event, 0, sizeof(event));
+				event.id = STOP_DISCONNECT;
+				session->queEvent(&event);
+				reg = NULL;
+			}
+		}
+
 		if(session->session_timer)
 		{
 			time(&now);
 			if(session->session_timer < now)
 			{
+				slog.debug("%s: sessione expired",
+					session->getLogname());
 				memset(&event, 0, sizeof(event));
 				event.id = STOP_DISCONNECT;
 				session->queEvent(&event);
