@@ -51,6 +51,164 @@ Session::~Session()
 	stopRTP();
 }
 
+void Session::redirect(const char *target, const char *encoding, unsigned char data, unsigned char dtmf)
+{
+	osip_message_t *msg = NULL;
+	char sdp[512];
+	char addr[65];
+	char *ep;
+	unsigned port;
+
+	setString(addr, sizeof(addr), target);
+	ep = strrchr(addr, ':');
+	*ep = 0;
+	port = atoi(++ep);
+
+	slog.debug("%s: redirecting %s to %s:%d",
+		logname, getSymbol("session.rtp_remote"), addr, port);
+
+	eXosip_lock();
+	eXosip_call_build_request(did, "INVITE", &msg);
+	if(!msg)
+	{
+		eXosip_unlock();
+		return;
+	}
+
+	osip_message_set_supported(msg, "100rel,replaces");
+
+	if(dtmf)
+		snprintf(sdp, sizeof(sdp),
+			"v=0\r\n"
+			"o=bayonne 0 0 IN IP4 %s\r\n"
+			"s=reinvite\r\n"
+			"c=IN IP4 %s\r\n"
+			"t=0 0\r\n"
+			"m=audio %d RTP/AVP %d %d\r\n"
+			"a=rtpmap:%d %s\r\n"
+			"a=rtpmap:%d telephone-events/8000\r\n",
+			addr, addr, port, data, dtmf,
+			data, encoding, dtmf);
+	else
+		snprintf(sdp, sizeof(sdp),
+			"v=0\r\n"
+			"o=bayonne 0 0 IN IP4 %s\r\n"
+			"s=reinvite\r\n"
+			"c=IN IP4 %s\r\n"
+			"t=0 0\r\n"
+			"m=audio %d RTP/AVP %d\r\n"
+			"a=rtpmap:%d %s\r\n",
+			addr, addr, port, data, data, encoding);
+	
+	osip_message_set_body(msg, sdp, strlen(sdp));
+	osip_message_set_content_type(msg, "application/sdp");
+	eXosip_call_send_request(did, msg);
+	eXosip_unlock();
+	reinvite = true;
+}	
+
+void Session::reconnect(void)
+{
+	const char *target = getSymbol("session.rtp_local");
+	const char *encoding = getSymbol("session.sdp_encoding");
+	
+	if(!encoding || !target || !reinvite)
+		return;
+
+	encoding = strchr(encoding, ' ');
+	if(!encoding)
+		return;
+	++encoding;
+	redirect(target, encoding, data_payload, dtmf_payload);
+	reinvite = false;
+}
+
+unsigned char Session::peerEvents(BayonneSession *s)
+{
+	const char *el = getSymbol("session.sdp_events");
+	const char *er = s->getSymbol("session.sdp_events");
+	unsigned char pl, pr, pe;
+
+	if(!el || !er)
+		return 255;
+
+	pe = peerEncoding(s);
+	if(!pe)
+		return 255;
+
+	pl = atoi(el + 9);
+	pr = atoi(er + 9);
+	if(pl == pr && pl != pe)
+		return pl;
+
+	if(pe != 101)
+		return 101;
+	else
+		return 102;
+}
+
+unsigned char Session::peerEncoding(BayonneSession *s)
+{
+	const char *evl = getSymbol("session.sdp_events");
+	const char *evr = s->getSymbol("session.sdp_events");
+	const char *cl = getSymbol("session.sdp_peering");
+	const char *cr = s->getSymbol("session.sdp_peering");
+	char *el;
+	unsigned char pl, pr;
+
+	char buf[65], rbuf[65];
+
+	if(evl && !evr)
+		return 255;
+
+	if(evr && !evl)
+		return 255;
+
+	if(!cl || !cr)
+		return 255;
+
+	if(evl && evr && !isPeering())
+		return 255;
+
+	if(evl && evr && !s->isPeering())
+		return 255;
+
+	pl = atoi(cl + 9);
+	pr = atoi(cr + 9);
+
+	cl = strchr(cl, ' ');
+	++cl;
+
+	cr = strchr(cr, ' ');
+	++cr;
+
+	setString(buf, sizeof(buf), cl);
+	el = strchr(buf, '/');
+	if(el)
+	{
+		el = strchr(++el, '/');
+		if(el && !stricmp(el, "/1"))
+			*el = 0;
+	}
+	
+	setString(rbuf, sizeof(rbuf), cr);
+	el = strchr(rbuf, '/');
+	if(el)
+	{
+		el = strchr(++el, '/');
+		if(el && !stricmp(el, "/1"))
+			*el = 0;
+	}
+
+	if(stricmp(buf, rbuf))
+		return 255;
+
+	if(pl == pr)
+		return pl;
+
+	return 98;
+}
+
 void Session::setEncoding(const char *encoding, timeout_t framing)
 {
 	if(codec)
@@ -189,9 +347,42 @@ bool Session::enterJoin(Event *event)
 	unsigned f1, f2;
 	timeout_t framing = getToneFraming(), duration;
 	struct dtmf2833 dtmfevent;
+	const char *target;
+	const char *encoding;
+	unsigned char data_peering, dtmf_peering;
 
 	switch(event->id)
 	{
+	case EXIT_PARTING:
+		if(reinvite && !isDisconnecting())
+			reconnect();
+		return false;
+	case ENTER_STATE:
+		reinvite = false;
+		if(!state.join.peer)
+		{
+			state.peering = false;
+			return false;
+		}
+		data_peering = peerEncoding(state.join.peer);
+		if(data_peering == 255)
+			return false;
+		dtmf_peering = peerEvents(state.join.peer);
+		if(dtmf_peering == 255)
+			dtmf_peering = 0;
+		encoding = state.join.peer->getSymbol("session.sdp_peering");
+		target = state.join.peer->getSymbol("session.rtp_remote");
+		if(encoding)
+			encoding = strchr(encoding, ' ');
+		if(encoding && target)
+			++encoding;
+		else
+		{
+			state.peering = false;
+			return false;
+		}
+		redirect(target, encoding, data_peering, dtmf_peering);
+		return false;
 	case AUDIO_SYNC:
 		rtp->syncAudio();
 		return true;
@@ -567,6 +758,11 @@ failure:
 			break;
 		}			
 		if(dtmf_payload)
+		{
+			snprintf(sdp, sizeof(sdp),
+				"a=rtpmap:%d telephone-events/8000",
+				dtmf_payload);
+			setConst("session.sdp_events", sdp);
                         snprintf(sdp, sizeof(sdp),
                                 "v=0\r\n"
                                 "o=bayonne 0 0 IN IP4 %s\r\n"
@@ -579,7 +775,7 @@ failure:
 				cp, cp, 
 				getLocalPort(), data_payload, dtmf_payload,
 				rtpmap, dtmf_payload);
-
+		}
 		else
 			snprintf(sdp, sizeof(sdp),
 				"v=0\r\n"
@@ -593,7 +789,9 @@ failure:
 				getLocalPort(), data_payload, 
 				rtpmap);
 
-		setConst("session.rtpmap", rtpmap);
+		setConst("session.sdp_encoding", rtpmap);
+		if(reg && reg->peering)
+			setConst("session.sdp_peering", rtpmap);
 
 		if(dtmf_sipinfo)
 			setConst("session.dtmfmode", "info");
