@@ -15,7 +15,9 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include "module.h"
+#ifndef	WIN32
 #include "private.h"
+#endif
 
 namespace moduleWebservice {
 using namespace ost;
@@ -40,6 +42,10 @@ void Session::htmlFooter(void)
 	if(!sl || !*sl)
 		sl = "up";
 
+#ifndef	VERSION
+#define	VERSION "w32"
+#endif
+
 	snprintf(buffer, sizeof(buffer),
 		"<HR>Bayonne server version " VERSION "; node=%s timeslots=%d service level=%s; running %s<BR>\r\n", 
 		server->getLast("servername"), ts_used, sl, dur);
@@ -166,6 +172,7 @@ void Session::htmlControl(void)
 		s = Bayonne::startDialing(qtarget, qscript, qcaller, qdisplay);
 		if(s)
 		{
+			s->setConst("session.manager", "webservice");
 			sid = s->getExternal("session.id");
 			success = true;
 			s->leave();
